@@ -215,12 +215,12 @@ class WafwebaclToApiGateway(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.IRestApi:
         return typing.cast(aws_cdk.aws_apigateway.IRestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="webacl")
     def webacl(self) -> aws_cdk.aws_wafv2.CfnWebACL:
         return typing.cast(aws_cdk.aws_wafv2.CfnWebACL, jsii.get(self, "webacl"))
@@ -251,7 +251,7 @@ class WafwebaclToApiGatewayProps:
         :summary: The properties for the WafwebaclToApiGateway class.
         '''
         if isinstance(webacl_props, dict):
-            webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+            webacl_props = CfnWebACLProps(**webacl_props)
         if __debug__:
             type_hints = typing.get_type_hints(WafwebaclToApiGatewayProps.__init__)
             check_type(argname="argument existing_api_gateway_interface", value=existing_api_gateway_interface, expected_type=type_hints["existing_api_gateway_interface"])
